@@ -14,6 +14,7 @@ try:
 except:
     import version
 import yaml
+import traceback
 from awscli.customizations.cloudformation.yamlhelper import yaml_parse
 
 logger = logging.getLogger(__name__)
@@ -161,10 +162,18 @@ def create_stack(stack_name: str, cfn_url: str, param_list: list, disable_rollba
         TemplateURL=cfn_url
     )
     
-    response = client.describe_stacks(
-        StackName=stack_name
-    )
-    if len(response['Stacks']) == 0:
+    stack_exists = False
+    try:
+        response = client.describe_stacks(
+            StackName=stack_name
+        )
+        if len(response['Stacks']) == 0:
+            stack_exists = True
+    except Exception as e:
+        logger.debug(e)
+        logger.debug(traceback.format_exc())
+        pass
+    if not stack_exists:
         if role_arn != None:
             response = client.create_stack(
                 StackName=stack_name,
@@ -339,7 +348,10 @@ def main():
     else:
         delete_bucket(bucket_name)
 
-    logger.info('Successfully to create stack: ' + stack['StackId'])
+    try:
+        logger.info('Successfully to create stack: ' + stack['StackId'])
+    except:
+        logger.error('Fail to create stack')
 
 if __name__ == "__main__":
     # execute only if run as a script
